.. redirect-from:: /users/prev_whats_new/github_stats_3.9.3

.. _github-stats-3-9-3:

GitHub statistics for 3.9.3 (Nov 30, 2024)
==========================================

GitHub statistics for 2024/08/12 (tag: v3.9.2) - 2024/11/30

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 6 issues and merged 62 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/95?closed=1>`__

The following 18 authors contributed 90 commits.

* Andresporcruz
* Antony Lee
* Charlie LeWarne
* dependabot[bot]
* Elliott Sales de Andrade
* Gavin S
* Greg Lucas
* hannah
* Kyle Sunden
* Kyra Cho
* kyracho
* Lumberbot (aka Jack)
* Michael Hinton
* Oscar Gustafsson
* Ruth Comer
* Thomas A Caswell
* Tim Hoffmann
* vittoboa

GitHub issues and pull requests:

Pull Requests (62):

* :ghpull:`29195`: Backport PR #29191 on branch v3.9.x (ci: Simplify 3.13t test setup)
* :ghpull:`29191`: ci: Simplify 3.13t test setup
* :ghpull:`29176`: Backport PR #29148 on branch v3.9.x (Don't fail on equal-but-differently-named cmaps in qt figureoptions.)
* :ghpull:`29148`: Don't fail on equal-but-differently-named cmaps in qt figureoptions.
* :ghpull:`29165`: Backport PR #29153 on branch v3.9.x (Bump codecov/codecov-action from 4 to 5 in the actions group)
* :ghpull:`29153`: Bump codecov/codecov-action from 4 to 5 in the actions group
* :ghpull:`29149`: Backport CI config updates to v3.9.x
* :ghpull:`29121`: Backport PR #29120 on branch v3.9.x (DOC: Switch nested pie example from cmaps to color_sequences)
* :ghpull:`29071`: Bump pypa/gh-action-pypi-publish from 1.10.3 to 1.11.0 in the actions group
* :ghpull:`29046`: Backport PR #28981 on branch v3.9.x (FIX: macos: Use standard NSApp run loop in our input hook)
* :ghpull:`28981`: FIX: macos: Use standard NSApp run loop in our input hook
* :ghpull:`29041`: Backport PR #29035 on branch v3.9.x (FIX: Don't set_wmclass on GTK3)
* :ghpull:`29035`: FIX: Don't set_wmclass on GTK3
* :ghpull:`29037`: Backport PR #29036 on branch v3.9.x (Don't pass redundant inline=True to example clabel() calls.)
* :ghpull:`29032`: Backport PR #27569 on branch v3.9.x (DOC: initial tags for statistics section of gallery)
* :ghpull:`29034`: Backport PR #29031 on branch v3.9.x (DOC: Fix copy-paste typo in ColorSequenceRegistry)
* :ghpull:`29031`: DOC: Fix copy-paste typo in ColorSequenceRegistry
* :ghpull:`29015`: Backport PR #29014 on branch v3.9.x (FIX: fake out setuptools scm in tox on ci)
* :ghpull:`29014`: FIX: fake out setuptools scm in tox on ci
* :ghpull:`29010`: Backport PR #29005 on branch v3.9.x (DOC: Update meson-python intersphinx link)
* :ghpull:`29006`: Backport PR #28993 on branch v3.9.x (FIX: contourf hatches use multiple edgecolors)
* :ghpull:`28993`: FIX: contourf hatches use multiple edgecolors
* :ghpull:`28988`: Backport PR #28987 on branch v3.9.x (Fix: Do not use numeric tolerances for axline special cases)
* :ghpull:`28947`: Backport PR #28925 on branch v3.9.x (TST: handle change in pytest.importorskip behavior)
* :ghpull:`28989`: Backport PR #28972 on branch v3.9.x (Switch macOS 12 runner images to macOS 13)
* :ghpull:`28972`: Switch macOS 12 runner images to macOS 13
* :ghpull:`28987`: Fix: Do not use numeric tolerances for axline special cases
* :ghpull:`28954`: Backport PR #28952 on branch v3.9.x (BLD: update trove metadata to support py3.13)
* :ghpull:`28952`: BLD: update trove metadata to support py3.13
* :ghpull:`28887`: Backport PR #28883 on branch v3.9.x (Only check X11 when running Tkinter tests)
* :ghpull:`28926`: Backport PR #28689 on branch v3.9.x (ci: Enable testing on Python 3.13)
* :ghpull:`28925`: TST: handle change in pytest.importorskip behavior
* :ghpull:`28945`: Backport PR #28943 on branch v3.9.x (DOC: Clarify the returned line of axhline()/axvline())
* :ghpull:`28939`: Backport PR #28900 on branch v3.9.x (DOC: Improve fancybox demo)
* :ghpull:`28900`: DOC: Improve fancybox demo
* :ghpull:`28902`: Backport PR #28881 on branch v3.9.x (Fix ``axline`` for slopes <= 1E-8. Closes #28386)
* :ghpull:`28431`: Fix ``axline`` for slopes < 1E-8
* :ghpull:`28881`: Fix ``axline`` for slopes <= 1E-8. Closes #28386
* :ghpull:`28883`: Only check X11 when running Tkinter tests
* :ghpull:`28859`: Backport PR #28858 on branch v3.9.x (Fix flaky labelcolor tests)
* :ghpull:`28858`: Fix flaky labelcolor tests
* :ghpull:`28839`: Backport PR #28836 on branch v3.9.x (MNT: Use __init__ parameters of font properties)
* :ghpull:`28836`: MNT: Use __init__ parameters of font properties
* :ghpull:`28828`: Backport PR #28818 on branch v3.9.x (Resolve configdir so that it's not a symlink when is_dir() is called)
* :ghpull:`28818`: Resolve configdir so that it's not a symlink when is_dir() is called
* :ghpull:`28811`: Backport PR #28810 on branch v3.9.x (Document how to obtain sans-serif usetex math.)
* :ghpull:`28806`: Backport PR #28805 on branch v3.9.x (add brackets to satisfy the new sequence requirement)
* :ghpull:`28802`: Backport PR #28798 on branch v3.9.x (DOC: Correctly list modules that have been internalized)
* :ghpull:`28791`: Backport PR #28790 on branch v3.9.x (DOC: Fix duplicate Figure.set_dpi entry)
* :ghpull:`28787`: Backport PR #28706 on branch v3.9.x (Add Returns info to to_jshtml docstring)
* :ghpull:`28706`: Add Returns info to to_jshtml docstring
* :ghpull:`28751`: Backport PR #28271 on branch v3.9.x (Fix draggable legend disappearing when picking while use_blit=True)
* :ghpull:`28271`: Fix draggable legend disappearing when picking while use_blit=True
* :ghpull:`28747`: Backport PR #28743 on branch v3.9.x (Minor fixes in ticker docs)
* :ghpull:`28743`: Minor fixes in ticker docs
* :ghpull:`28738`: Backport PR #28737 on branch v3.9.x (TST: Fix image comparison directory for test_striped_lines)
* :ghpull:`28740`: Backport PR #28739 on branch v3.9.x (Tweak interactivity docs wording (and fix capitalization).)
* :ghpull:`28737`: TST: Fix image comparison directory for test_striped_lines
* :ghpull:`28733`: Backport PR #28732 on branch v3.9.x (Renames the minumumSizeHint method to minimumSizeHint)
* :ghpull:`28732`: Renames the minumumSizeHint method to minimumSizeHint
* :ghpull:`28689`: ci: Enable testing on Python 3.13
* :ghpull:`28724`: Backport fixes from #28711

Issues (6):

* :ghissue:`28960`: [Bug]: High CPU utilization of the macosx backend
* :ghissue:`28990`: [Bug]: no longer able to set multiple hatch colors
* :ghissue:`28870`: [Bug]: axline doesn't work with some axes scales
* :ghissue:`28386`: [Bug]: Minor issue - Drawing an axline sets slopes less than 1E-8 to 0
* :ghissue:`28817`: [Bug]: ``~/.config/matplotlib`` is never used because ``~/.config`` is a symlink
* :ghissue:`28716`: Size hint method in Qt backend should be named ``minimumSizeHint``, not ``minumumSizeHint``
